from pydantic import BaseModel, EmailStr, Field
from typing import Optional
from datetime import datetime
import uuid

class ContactFormBase(BaseModel):
    name: str = Field(..., description="Contact name")
    email: EmailStr = Field(..., description="Contact email address")
    message: str = Field(..., description="Contact message")

class ContactFormCreate(ContactFormBase):
    pass

class ContactFormUpdate(ContactFormBase):
    name: Optional[str] = Field(None, description="Contact name")
    email: Optional[EmailStr] = Field(None, description="Contact email address")
    message: Optional[str] = Field(None, description="Contact message")

class ContactFormSchema(ContactFormBase):
    id: uuid.UUID
    created_at: datetime
    updated_at: datetime

    class Config:
        orm_mode = True